@@ -7,11 +7,18 @@ from .list import ListBreadcrumbMixin
 class DeleteBreadcrumbMixin(ListBreadcrumbMixin):
     @classproperty
     def delete_view_name(self):
-        return action_view_name(self.model, self.delete_view_suffix, full=False)
+        return action_view_name(
+            model=self.model,
+            action=self.delete_view_suffix,
+            app_name=self.app_name,
+            full=False,
+        )
 
     @property
     def __delete_view_name(self):
-        return action_view_name(self.model, self.detail_view_suffix)
+        return action_view_name(
+            model=self.model, action=self.detail_view_suffix, app_name=self.app_name
+        )
 
     def delete_view_url(self, instance):
         if self.breadcrumb_use_pk:
